@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::HumanDateParsingModules::Startup;
 
-our $VERSION = 0.006; # VERSION
+our $VERSION = 0.007; # VERSION
 
 our $results = [
   [
@@ -8,70 +8,70 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.00015,
-        mod_overhead_time => 94.4,
+        errors => 0.00021,
+        mod_overhead_time => 114,
         participant => "DateTime::Format::Flexible",
         proc_private_dirty_size => 16,
         proc_rss_size => 20,
-        proc_size => 56,
+        proc_size => 60,
         samples => 20,
-        time => 100,
+        time => 120,
         vs_slowest => 1,
       },
       {
-        errors => 0.0001,
-        mod_overhead_time => 86.4,
+        errors => 0.00022,
+        mod_overhead_time => 104,
         participant => "DateTime::Format::Natural",
         proc_private_dirty_size => 11,
         proc_rss_size => 15,
-        proc_size => 44,
-        samples => 21,
-        time => 92,
-        vs_slowest => 1.087,
+        proc_size => 48,
+        samples => 20,
+        time => 110,
+        vs_slowest => 1.0909,
       },
       {
-        errors => 6.8e-05,
-        mod_overhead_time => 55.4,
+        errors => 0.00018,
+        mod_overhead_time => 66,
         participant => "DateTime",
         proc_private_dirty_size => 0.82,
         proc_rss_size => 4.1,
-        proc_size => 16,
+        proc_size => 20,
         samples => 20,
-        time => 61,
-        vs_slowest => 1.6393,
-      },
-      {
-        errors => 3.5e-05,
-        mod_overhead_time => 16.4,
-        participant => "DateTime::Format::Alami::ID",
-        proc_private_dirty_size => 16,
-        proc_rss_size => 20,
-        proc_size => 56,
-        samples => 20,
-        time => 22,
-        vs_slowest => 4.5455,
+        time => 72,
+        vs_slowest => 1.6667,
       },
       {
         errors => 6.2e-05,
-        mod_overhead_time => 16.4,
+        mod_overhead_time => 19,
+        participant => "DateTime::Format::Alami::ID",
+        proc_private_dirty_size => 16,
+        proc_rss_size => 20,
+        proc_size => 60,
+        samples => 20,
+        time => 25,
+        vs_slowest => 4.8,
+      },
+      {
+        errors => 5.7e-05,
+        mod_overhead_time => 19,
         participant => "DateTime::Format::Alami::EN",
         proc_private_dirty_size => 2.8,
         proc_rss_size => 6.4,
-        proc_size => 20,
+        proc_size => 24,
         samples => 20,
-        time => 22,
-        vs_slowest => 4.5455,
+        time => 25,
+        vs_slowest => 4.8,
       },
       {
-        errors => 2.2e-05,
+        errors => 2.1e-05,
         mod_overhead_time => 0,
         participant => "perl -e1 (baseline)",
-        proc_private_dirty_size => 2.7,
-        proc_rss_size => 6.2,
-        proc_size => 20,
+        proc_private_dirty_size => 2.8,
+        proc_rss_size => 6.4,
+        proc_size => 24,
         samples => 20,
-        time => 5.6,
-        vs_slowest => 17.857,
+        time => 6,
+        vs_slowest => 20,
       },
     ],
     {
@@ -119,7 +119,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -142,7 +141,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -150,20 +148,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -172,30 +166,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2823.187,
-                                              stepping                     => 4,
+                                              speed                        => 3269.046,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -234,7 +214,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -257,7 +236,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -265,20 +243,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -287,30 +261,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2659.617,
-                                              stepping                     => 4,
+                                              speed                        => "3204.140",
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -349,7 +309,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -372,7 +331,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -380,20 +338,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -402,30 +356,16 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2668.531,
-                                              stepping                     => 4,
+                                              speed                        => 3200.871,
+                                              stepping                     => 7,
                                             },
                                             {
                                               address_width                => 64,
@@ -464,7 +404,6 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
-                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -487,7 +426,6 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
-                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -495,20 +433,16 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
-                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
-                                                                                "f16c",
-                                                                                "rdrand",
                                                                                 "lahf_lm",
-                                                                                "abm",
-                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
+                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -517,41 +451,27 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
-                                                                                "fsgsbase",
-                                                                                "tsc_adjust",
-                                                                                "bmi1",
-                                                                                "hle",
-                                                                                "avx2",
-                                                                                "smep",
-                                                                                "bmi2",
-                                                                                "erms",
-                                                                                "invpcid",
-                                                                                "rtm",
-                                                                                "rdseed",
-                                                                                "adx",
-                                                                                "smap",
-                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "4096 KB" },
+                                              L2_cache                     => { max_cache_size => "6144 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 61,
-                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
-                                              number_of_cores              => 2,
+                                              model                        => 42,
+                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
+                                              number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2735.851,
-                                              stepping                     => 4,
+                                              speed                        => 3252.457,
+                                              stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 7.39506888389587,
+      "func.elapsed_time"              => 9.01010203361511,
       "func.module_startup"            => 1,
       "func.module_versions"           => {
-                                            "__PACKAGE__"                                         => 1.034,
+                                            "__PACKAGE__"                                         => 1.036,
                                             "Bencher::Scenario::HumanDateParsingModules::Startup" => undef,
                                             "Benchmark::Dumb"                                     => "0.10",
                                             "DateTime"                                            => 1.36,
-                                            "DateTime::Format::Alami::EN"                         => 0.13,
-                                            "DateTime::Format::Alami::ID"                         => 0.13,
+                                            "DateTime::Format::Alami::EN"                         => 0.14,
+                                            "DateTime::Format::Alami::ID"                         => 0.14,
                                             "DateTime::Format::Flexible"                          => 0.26,
                                             "DateTime::Format::Natural"                           => 1.04,
                                             "Devel::Platform::Info"                               => 0.16,
@@ -562,24 +482,24 @@ our $results = [
       "func.permute"                   => ["participant", [0 .. 5], "perl", ["perl"]],
       "func.platform_info"             => {
                                             archname => "x86_64",
-                                            codename => "rosa",
+                                            codename => "jessie",
                                             is32bit  => 0,
                                             is64bit  => 1,
-                                            kernel   => "linux-3.19.0-32-generic",
+                                            kernel   => "linux-3.16.0-4-amd64",
                                             kname    => "Linux",
-                                            kvers    => "3.19.0-32-generic",
+                                            kvers    => "3.16.0-4-amd64",
                                             osflag   => "linux",
-                                            oslabel  => "LinuxMint",
+                                            oslabel  => "Debian",
                                             osname   => "GNU/Linux",
-                                            osvers   => 17.3,
+                                            osvers   => "8.0",
                                             source   => {
                                                           "cat /etc/.issue" => "",
-                                                          "cat /etc/issue"  => "Linux Mint 17.3 Rosa \\n \\l",
-                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 17.3 Rosa\nRelease:\t17.3\nCodename:\trosa",
-                                                          "uname -a"        => "Linux backpacker 3.19.0-32-generic #37~14.04.1-Ubuntu SMP Thu Oct 22 09:41:40 UTC 2015 x86_64 x86_64 x86_64 GNU/Linux",
+                                                          "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
+                                                          "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
+                                                          "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.36-1+deb8u2 (2016-10-19) x86_64 GNU/Linux",
                                                           "uname -m"        => "x86_64",
                                                           "uname -o"        => "GNU/Linux",
-                                                          "uname -r"        => "3.19.0-32-generic",
+                                                          "uname -r"        => "3.16.0-4-amd64",
                                                           "uname -s"        => "Linux",
                                                         },
                                           },
@@ -589,9 +509,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1468714132,
       "func.scenario_module_sha1sum"   => "e0097c246fde04c2a3fc666d8e1cff95493b3722",
       "func.scenario_module_sha256sum" => "a30b9d62ec42cd593ad183a5a027548e333705675b193cf3c431201ae583893c",
-      "func.time_end"                  => 1485330406.82101,
+      "func.time_end"                  => 1497004367.88775,
       "func.time_factor"               => 1,
-      "func.time_start"                => 1485330399.42595,
+      "func.time_start"                => 1497004358.87765,
       "table.field_aligns"             => [
                                             "left",
                                             "left",
